Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsConnectionDying ¶
func IsConnectionDying(conn *Connection) bool
Types ¶
type Connection ¶
type Connection struct {
// Fields from conntrack flows
ID uint32
Timeout uint32
StartTime time.Time
// For invalid and closed connections: StopTime is the time when connection was updated last.
// For established connections: StopTime is latest time when it was polled.
StopTime time.Time
// IsPresent flag helps in cleaning up connections when they are not in conntrack table anymore.
IsPresent bool
// DoneExport marks whether the related flow records are already exported or not so that we can
// safely delete the connection from the connection map.
DoneExport bool
Zone uint16
Mark uint32
StatusFlag uint32
Labels, LabelsMask []byte
// TODO: Have a separate field for protocol. No need to keep it in Tuple.
TupleOrig, TupleReply Tuple
OriginalPackets, OriginalBytes uint64
ReversePackets, ReverseBytes uint64
// Fields specific to Antrea
SourcePodNamespace string
SourcePodName string
DestinationPodNamespace string
DestinationPodName string
DestinationServicePortName string
IngressNetworkPolicyName string
IngressNetworkPolicyNamespace string
EgressNetworkPolicyName string
EgressNetworkPolicyNamespace string
TCPState string
}
type ConnectionKey ¶
type ConnectionKey [5]string
func NewConnectionKey ¶
func NewConnectionKey(conn *Connection) ConnectionKey
NewConnectionKey creates 5-tuple of flow as connection key
type ConnectionMapCallBack ¶
type ConnectionMapCallBack func(key ConnectionKey, conn *Connection) error
type FlowRecord ¶
type FlowRecordCallBack ¶
type FlowRecordCallBack func(key ConnectionKey, record FlowRecord) error
Click to show internal directories.
Click to hide internal directories.