Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HeliosDP ¶
type HeliosDP interface {
// Overlay APIs
CreateVXLAN(name string, vxlanId int, tunSrc string, tunDst string) (string, error)
DeleteVXLAN(name string) error
CreateIPSec(name string, csum bool, localIP string, remoteIP string, psk string, externalIDs map[string]interface{}) (string, error)
DeleteIPSec(name string) error
// Route APIs
// AddRoutes should add routes to the provided podCIDR.
// It should override the routes if they already exist, without error.
AddRoutes(podCIDR *net.IPNet, peerNodeName string, peerNodeIP, peerGwIP net.IP) error
// DeleteRoutes should delete routes to the provided podCIDR.
// It should do nothing if the routes don't exist, without error.
DeleteRoutes(podCIDR *net.IPNet) error
// MigrateRoutesToGw should move routes from device linkname to local gateway.
MigrateRoutesToGw(linkName string) error
// UnMigrateRoutesFromGw should move routes back from local gateway to original device linkName
// if linkName is nil, it should remove the routes.
UnMigrateRoutesFromGw(route *net.IPNet, linkName string) error
}
HeliosDP helps list Loggers.
Click to show internal directories.
Click to hide internal directories.